Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(514)

Unified Diff: components/payments/core/journey_logger.h

Issue 2790253002: [Payments] Don't record CanMakePayment when in incognito mode. (Closed)
Patch Set: Addressed comments Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/payments/core/journey_logger.h
diff --git a/components/payments/core/journey_logger.h b/components/payments/core/journey_logger.h
index 5c35c0d7ecfa3015fcc4fd653f6d092183858a6d..326704e11041061b5473a69c1809cc33a81bdad7 100644
--- a/components/payments/core/journey_logger.h
+++ b/components/payments/core/journey_logger.h
@@ -53,7 +53,7 @@ class JourneyLogger {
static const int CMP_SHOW_COULD_MAKE_PAYMENT_ = 1 << 1;
static const int CMP_SHOW_MAX = 4;
- JourneyLogger();
+ explicit JourneyLogger(bool is_incognito);
~JourneyLogger();
// Increments the number of selection adds for the specified section.
@@ -112,7 +112,8 @@ class JourneyLogger {
// merchant.
void RecordSectionSpecificStats(CompletionStatus completion_status);
// Records the metrics related the the CanMakePayment method.
void RecordCanMakePaymentStats(CompletionStatus completion_status);
// Records CanMakePayment's return value effect on whether the Payment Request
@@ -128,6 +129,7 @@ class JourneyLogger {
bool was_can_make_payments_used_;
bool could_make_payment_;
bool was_show_called_;
+ bool is_incognito_;
DISALLOW_COPY_AND_ASSIGN(JourneyLogger);
};
« no previous file with comments | « components/payments/content/android/journey_logger_android.cc ('k') | components/payments/core/journey_logger.cc » ('j') | no next file with comments »
@@ -112,7 +112,8 @@ class JourneyLogger {
// merchant.
void RecordSectionSpecificStats(CompletionStatus completion_status);
- // Records the metrics related the the CanMakePayment method.
+ // Records the metrics related the the CanMakePayment method unless in
+ // incognito mode.
void RecordCanMakePaymentStats(CompletionStatus completion_status);
// Records CanMakePayment's return value effect on whether the Payment Request

Powered by Google App Engine
This is Rietveld 408576698